@@ -49,7 +49,9 @@ expsampleN.noninf <- function(alpha=0.025, targetpower=0.8, logscale=TRUE,
     n  <- n + 1
     df <- eval(dfe)
   }
-  nmin <- n
+  # make a multiple of steps
+  nmin <- as.integer(steps*trunc(n/steps)) 
+  nmin <- nmin + steps*(nmin<n)
   
   if (missing(CV) | missing(dfCV)) {
     stop("CV and its df must be given!", call.=FALSE)
